<!DOCTYPE TS><TS>
<context>
    <name></name>
    <message>
        <source>UNKNOWN CUT</source>
        <translation type="obsolete">Unbekannter Cut</translation>
    </message>
</context>
<context>
    <name>@default</name>
    <message>
        <source>ALL</source>
        <translation type="obsolete">ALLE</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Couldn&apos;t initialize QSql driver!</source>
        <translation>Qsql-Treiber konnte nicht initialisiert werden!</translation>
    </message>
    <message>
        <source>Couldn&apos;t open mySQL connection!</source>
        <translation>Konnte keine Verbindung zum mySQL-Server herstellen!</translation>
    </message>
    <message>
        <source>Sequentially</source>
        <translation type="unfinished">Sequentiell</translation>
    </message>
    <message>
        <source>Randomly</source>
        <translation type="unfinished">Zufällig</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">Unbekannt</translation>
    </message>
    <message>
        <source>Feature</source>
        <translation type="unfinished">Feature</translation>
    </message>
    <message>
        <source>Theme Open</source>
        <translation type="unfinished">Thema Anfang</translation>
    </message>
    <message>
        <source>Theme Close</source>
        <translation type="unfinished">Thema Ende</translation>
    </message>
    <message>
        <source>Theme Open/Close</source>
        <translation type="unfinished">Thema Anfang/Ende</translation>
    </message>
    <message>
        <source>Background</source>
        <translation type="unfinished">Hintergrund</translation>
    </message>
    <message>
        <source>Commercial/Jingle/Promo</source>
        <translation type="unfinished">Commercial/Jingle/Promo</translation>
    </message>
    <message>
        <source>UNKNOWN CUT</source>
        <translation type="unfinished">Unbekannter Cut</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="unfinished">Handbuch</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished">Play</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="unfinished">Segue</translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished">Zeit</translation>
    </message>
    <message>
        <source>Panel</source>
        <translation type="unfinished">Panel</translation>
    </message>
    <message>
        <source>Macro</source>
        <translation type="unfinished">Makro</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="unfinished">PLAY</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="unfinished">SEGUE</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished">STOP</translation>
    </message>
    <message>
        <source>UNKNOWN</source>
        <translation type="unfinished">UNBEKANNT</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished">Audio</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation type="unfinished">Marker</translation>
    </message>
    <message>
        <source>Open Bracket</source>
        <translation type="unfinished">Klammer öffnen</translation>
    </message>
    <message>
        <source>Close Bracket</source>
        <translation type="unfinished">Klammer schließen</translation>
    </message>
    <message>
        <source>ChainTo</source>
        <translation type="unfinished">ChainTo</translation>
    </message>
    <message>
        <source>Track</source>
        <translation type="unfinished">Track</translation>
    </message>
    <message>
        <source>Link</source>
        <translation type="unfinished">Link</translation>
    </message>
    <message>
        <source>Traffic</source>
        <translation type="unfinished">Traffic</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished">Musik</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation type="unfinished">RDLogManager</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation type="unfinished">Tracker</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation type="unfinished">Aufnahme</translation>
    </message>
    <message>
        <source>Macro Event</source>
        <translation type="unfinished">Makro Event</translation>
    </message>
    <message>
        <source>Switch Event</source>
        <translation type="unfinished">Schalt-Event</translation>
    </message>
    <message>
        <source>Playout</source>
        <translation type="unfinished">Playout</translation>
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished">Download</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation type="unfinished">Upload</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished">Ok</translation>
    </message>
    <message>
        <source>Short Length</source>
        <translation type="unfinished">Kurze Länge</translation>
    </message>
    <message>
        <source>Low Level</source>
        <translation type="unfinished">Niedriger Level</translation>
    </message>
    <message>
        <source>High Level</source>
        <translation type="unfinished">Hoher Level</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="unfinished">Herunterladen</translation>
    </message>
    <message>
        <source>Uploading</source>
        <translation type="unfinished">Hochladen</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation type="unfinished">Serverfehler</translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="unfinished">Interner Fehler</translation>
    </message>
    <message>
        <source>Interrupted</source>
        <translation type="unfinished">Unterbrochen</translation>
    </message>
    <message>
        <source>Playing</source>
        <translation type="unfinished">Abspielen</translation>
    </message>
    <message>
        <source>Waiting</source>
        <translation type="unfinished">Warten</translation>
    </message>
    <message>
        <source>Device Busy</source>
        <translation type="unfinished">Gerät beschäftigt</translation>
    </message>
    <message>
        <source>No Such Cart/Cut</source>
        <translation type="unfinished">Kein solcher Cart/Cut</translation>
    </message>
    <message>
        <source>Unknown Audio Format</source>
        <translation type="unfinished">Unbekanntes Audioformat</translation>
    </message>
    <message>
        <source>CBSI DeltaFlex Traffic Reconciliation v2.01</source>
        <translation type="unfinished">CBSI DeltaFlex Traffic Reconciliation v2.01</translation>
    </message>
    <message>
        <source>Text Log</source>
        <translation type="unfinished">Text Log</translation>
    </message>
    <message>
        <source>ASCAP/BMI Electronic Music Report</source>
        <translation type="unfinished">ASCAP/BMI Electronic Music Report</translation>
    </message>
    <message>
        <source>Technical Playout Report</source>
        <translation type="unfinished">Technical Playout Report</translation>
    </message>
    <message>
        <source>SoundExchange Statutory License Report</source>
        <translation type="unfinished">SoundExchange Statutory License Report</translation>
    </message>
    <message>
        <source>RadioTraffic.com Traffic Reconciliation</source>
        <translation type="unfinished">RadioTraffic.com Traffic Reconciliation</translation>
    </message>
    <message>
        <source>VisualTraffic Reconciliation</source>
        <translation type="unfinished">VisualTraffic Reconciliation</translation>
    </message>
    <message>
        <source>CounterPoint Traffic Reconciliation</source>
        <translation type="unfinished">CounterPoint Traffic Reconciliation</translation>
    </message>
    <message>
        <source>Music1 Reconciliation</source>
        <translation type="unfinished">Music1 Reconciliation</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished">Andere</translation>
    </message>
    <message>
        <source>AM</source>
        <translation type="unfinished">AM</translation>
    </message>
    <message>
        <source>FM</source>
        <translation type="unfinished">FM</translation>
    </message>
    <message>
        <source>Report complete!</source>
        <translation type="unfinished">Report vollständig!</translation>
    </message>
    <message>
        <source>Report canceled!</source>
        <translation type="unfinished">Report abgebrochen!</translation>
    </message>
    <message>
        <source>Unable to open report file!</source>
        <translation type="unfinished">Kann Reportdatei nicht öffnen!</translation>
    </message>
    <message>
        <source>Music Summary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WideOrbit Traffic Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NPR/DS SoundExchange Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music Playout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Log Output 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Log Output 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel First Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux Log 1 Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux Log 2 Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel Second Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel Third Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel Fourth Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audition/Cue Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel Fifth and Later Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>invalid SQL or failed DB connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished">Alles</translation>
    </message>
    <message>
        <source>Relative</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NaturalLog Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LiveAssist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classical Music Playout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>reserved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mr. Master Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spin Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>promo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fade</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NoTime</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDAddCart</name>
    <message>
        <source>&amp;Group:</source>
        <translation>&amp;Gruppe:</translation>
    </message>
    <message>
        <source>&amp;New Cart Number:</source>
        <translation>&amp;Neue Cartnummer:</translation>
    </message>
    <message>
        <source>&amp;New Cart Type:</source>
        <translation>&amp;Neuer Cart-Typ:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Macro</source>
        <translation>Makro</translation>
    </message>
    <message>
        <source>[new cart]</source>
        <translation>[neuer Cart]</translation>
    </message>
    <message>
        <source>&amp;New Cart Title:</source>
        <translation>&amp;Neuer Cart-Titel:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>No Available Cart Numbers</source>
        <translation>Keine Cartnummern verfügbar</translation>
    </message>
    <message>
        <source>There are no more available cart numbers for the group!</source>
        <translation>Es gibt keine weiteren verfügbaren Cartnummern für die Gruppe!</translation>
    </message>
    <message>
        <source>Invalid Number</source>
        <translation>Ungültige Zahl</translation>
    </message>
    <message>
        <source>Invalid Cart Number!</source>
        <translation>Ungültige Cartnummer!</translation>
    </message>
    <message>
        <source>Title Required</source>
        <translation>Titel benötigt</translation>
    </message>
    <message>
        <source>You must enter a cart title!</source>
        <translation>Sie müssen einen Cart-Titel eingeben!</translation>
    </message>
    <message>
        <source>The cart number is outside of the permitted range for this group!</source>
        <translation>Die Cartnummer befindet sich außerhalb des für diese Gruppe erlaubten Bereichs!</translation>
    </message>
    <message>
        <source>Cart Exists</source>
        <translation>Cart existiert</translation>
    </message>
    <message>
        <source>This cart already exists.</source>
        <translation>Dieser Cart existiert bereits.</translation>
    </message>
    <message>
        <source>Duplicate Title</source>
        <translation>Doppelter Titel</translation>
    </message>
    <message>
        <source>The cart title must be unique!</source>
        <translation>Der Cart-Titel muss einzigartig sein!</translation>
    </message>
</context>
<context>
    <name>RDAddLog</name>
    <message>
        <source>Create Log</source>
        <translation>Log erstellen</translation>
    </message>
    <message>
        <source>&amp;New Log Name:</source>
        <translation>&amp;Name des neuen Logs:</translation>
    </message>
    <message>
        <source>&amp;Service:</source>
        <translation>&amp;Service:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation>RDLogEdit</translation>
    </message>
    <message>
        <source>The name is invalid!</source>
        <translation type="obsolete">Der Name ist ungültig!</translation>
    </message>
    <message>
        <source>The service is invalid!</source>
        <translation>Der Service ist ungültig!</translation>
    </message>
</context>
<context>
    <name>RDAudioSettingsDialog</name>
    <message>
        <source>Edit Settings</source>
        <translation>Einstellungen editieren</translation>
    </message>
    <message>
        <source>Default &amp;Format:</source>
        <translation>Standard &amp;Format:</translation>
    </message>
    <message>
        <source>Default &amp;Channels:</source>
        <translation>Standard &amp;Kanäle:</translation>
    </message>
    <message>
        <source>Default &amp;Sample Rate:</source>
        <translation>Standard &amp;Sample Rate:</translation>
    </message>
    <message>
        <source>Default &amp;Bitrate:</source>
        <translation>Standard &amp;Bitrate:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>PCM16</source>
        <translation>PCM16</translation>
    </message>
    <message>
        <source>OggVorbis</source>
        <translation>OggVorbis</translation>
    </message>
    <message>
        <source>MPEG Layer 2</source>
        <translation>MPEG Layer 2</translation>
    </message>
    <message>
        <source>MPEG Layer 3</source>
        <translation>MPEG Layer 3</translation>
    </message>
</context>
<context>
    <name>RDButtonDialog</name>
    <message>
        <source>Edit Button</source>
        <translation>Edit Schaltfläche</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation>Label:</translation>
    </message>
    <message>
        <source>Cart:</source>
        <translation>Cart:</translation>
    </message>
    <message>
        <source>Set
Cart</source>
        <translation>Cart
einstellen</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Set
Color</source>
        <translation>Farbe
setzen</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>NOT FOUND</source>
        <translation>NICHT GEFUNDEN</translation>
    </message>
</context>
<context>
    <name>RDCardSelector</name>
    <message>
        <source>Card:</source>
        <translation>Karte:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
</context>
<context>
    <name>RDCart</name>
    <message>
        <source>Sequentially</source>
        <translation type="obsolete">Sequentiell</translation>
    </message>
    <message>
        <source>Randomly</source>
        <translation type="obsolete">Zufällig</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Unbekannt</translation>
    </message>
    <message>
        <source>Feature</source>
        <translation type="obsolete">Feature</translation>
    </message>
    <message>
        <source>Theme Open</source>
        <translation type="obsolete">Thema Anfang</translation>
    </message>
    <message>
        <source>Theme Close</source>
        <translation type="obsolete">Thema Ende</translation>
    </message>
    <message>
        <source>Theme Open/Close</source>
        <translation type="obsolete">Thema Anfang/Ende</translation>
    </message>
    <message>
        <source>Background</source>
        <translation type="obsolete">Hintergrund</translation>
    </message>
    <message>
        <source>Commercial/Jingle/Promo</source>
        <translation type="obsolete">Commercial/Jingle/Promo</translation>
    </message>
</context>
<context>
    <name>RDCartDialog</name>
    <message>
        <source>Select Cart</source>
        <translation>Cart auswählen</translation>
    </message>
    <message>
        <source>Please Wait...</source>
        <translation>Bitte warten...</translation>
    </message>
    <message>
        <source>Cart Filter:</source>
        <translation>Cart Filter:</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Suchen</translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <source>NUMBER</source>
        <translation>NUMMER</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation>LÄNGE</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TITEL</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation>KÜNSTLER</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation>GRUPPE</translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation>KUNDE</translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation>AGENTUR</translation>
    </message>
    <message>
        <source>USER DEF</source>
        <translation>BENUTZER DEF</translation>
    </message>
    <message>
        <source>START</source>
        <translation>START</translation>
    </message>
    <message>
        <source>END</source>
        <translation>END</translation>
    </message>
    <message>
        <source>Send to
&amp;Editor</source>
        <translation>An &amp;Editor
senden</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>ALLE</translation>
    </message>
    <message>
        <source>Show Only First</source>
        <translation>Zeige nur erste</translation>
    </message>
    <message>
        <source>Matches</source>
        <translation>Treffer</translation>
    </message>
    <message>
        <source>Scheduler Code:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load From
&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create temporary cart for import!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to get temporary cart number for import!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation type="unfinished">Importfehler</translation>
    </message>
    <message>
        <source>Imported from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COMPOSER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CONDUCTOR</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDCueEdit</name>
    <message>
        <source>&amp;Audition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished">Ende</translation>
    </message>
    <message>
        <source>&amp;Recue</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDCueEditDialog</name>
    <message>
        <source>Set Cue Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDCutDialog</name>
    <message>
        <source>Select Cut</source>
        <translation>Cut auswählen</translation>
    </message>
    <message>
        <source>Please Wait...</source>
        <translation>Bitte warten...</translation>
    </message>
    <message>
        <source>Cart Filter:</source>
        <translation>Cart-Filter:</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Suchen</translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <source>Carts</source>
        <translation>Carts</translation>
    </message>
    <message>
        <source>NUMBER</source>
        <translation>NUMMER</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TITEL</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation>GRUPPE</translation>
    </message>
    <message>
        <source>Cuts</source>
        <translation>Cuts</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>BESCHREIBUNG</translation>
    </message>
    <message>
        <source>&amp;Add New
Cart</source>
        <translation>Neuen C&amp;art hinzufügen</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>ALLE</translation>
    </message>
    <message>
        <source>Show Only First</source>
        <translation>Zeige nur erste</translation>
    </message>
    <message>
        <source>Matches</source>
        <translation>Treffer</translation>
    </message>
    <message>
        <source>Scheduler Code:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDDateDialog</name>
    <message>
        <source>Select Date</source>
        <translation>Datum wählen</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
</context>
<context>
    <name>RDDatePicker</name>
    <message>
        <source>Mo</source>
        <translation>Mo</translation>
    </message>
    <message>
        <source>Tu</source>
        <translation>Di</translation>
    </message>
    <message>
        <source>We</source>
        <translation>Mi</translation>
    </message>
    <message>
        <source>Th</source>
        <translation>Do</translation>
    </message>
    <message>
        <source>Fr</source>
        <translation>Fr</translation>
    </message>
    <message>
        <source>Sa</source>
        <translation>Sa</translation>
    </message>
    <message>
        <source>Su</source>
        <translation>So</translation>
    </message>
</context>
<context>
    <name>RDEditAudio</name>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <source>Amplitude</source>
        <translation>Amplitude</translation>
    </message>
    <message>
        <source>Zoom
In</source>
        <translation>hineinzoomen</translation>
    </message>
    <message>
        <source>Zoom
Out</source>
        <translation>herauszoomen</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Zeit</translation>
    </message>
    <message>
        <source>Full
In</source>
        <translation>Full
In</translation>
    </message>
    <message>
        <source>Full
Out</source>
        <translation>Full
Out</translation>
    </message>
    <message>
        <source>Goto</source>
        <translation>Gehe zu</translation>
    </message>
    <message>
        <source>Cursor</source>
        <translation>Cursor</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Ende</translation>
    </message>
    <message>
        <source>Cut
Start</source>
        <translation>Cut
Start</translation>
    </message>
    <message>
        <source>Cut
End</source>
        <translation>Cut
Ende</translation>
    </message>
    <message>
        <source>Talk
Start</source>
        <translation>Mod
Start</translation>
    </message>
    <message>
        <source>Segue
Start</source>
        <translation>Segue
Start</translation>
    </message>
    <message>
        <source>Segue
End</source>
        <translation>Segue
Ende</translation>
    </message>
    <message>
        <source>Fade
Up</source>
        <translation>Einfaden</translation>
    </message>
    <message>
        <source>Hook
Start</source>
        <translation>Hook
Start</translation>
    </message>
    <message>
        <source>Hook
End</source>
        <translation>Hook
Ende</translation>
    </message>
    <message>
        <source> dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <source>Threshold</source>
        <translation>Threshold</translation>
    </message>
    <message>
        <source>Trim
Start</source>
        <translation>Trim
Start</translation>
    </message>
    <message>
        <source>Trim
End</source>
        <translation>Trim
Ende</translation>
    </message>
    <message>
        <source>Cut Gain</source>
        <translation>Cut Gain</translation>
    </message>
    <message>
        <source>Remove
Marker</source>
        <translation>Marker
entfernen</translation>
    </message>
    <message>
        <source>No Fade on Segue Out</source>
        <translation>Kein Fade bei Seque Out</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Länge</translation>
    </message>
    <message>
        <source>Delete Talk Markers</source>
        <translation>Mod.-Marker entfernen</translation>
    </message>
    <message>
        <source>Delete Segue Markers</source>
        <translation>Segue-Marker entfernen</translation>
    </message>
    <message>
        <source>Delete Hook Markers</source>
        <translation>Hook-Marker entfernen</translation>
    </message>
    <message>
        <source>Delete Fade Up Marker</source>
        <translation>Ein-Fade Marker entfernen</translation>
    </message>
    <message>
        <source>Delete Fade Down Marker</source>
        <translation>Aus-Fade Marker entfernen</translation>
    </message>
    <message>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <source>&lt;none&gt;</source>
        <translation>&lt;nichts&gt;</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cut</translation>
    </message>
    <message>
        <source>Talk</source>
        <translation>Mod</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Segue</translation>
    </message>
    <message>
        <source>Hook</source>
        <translation>Hook</translation>
    </message>
    <message>
        <source>Fade Up</source>
        <translation>Einfaden</translation>
    </message>
    <message>
        <source>Fade Down</source>
        <translation>Ausfaden</translation>
    </message>
    <message>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <source>Rivendell Web Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to download peak data, error was:
&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Less than half of the audio is playable with these marker settings.
Are you sure you want to save?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More than half of the audio will be faded with these marker settings.
Are you sure you want to save?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDEditPanelName</name>
    <message>
        <source>Edit Panel Name</source>
        <translation>Namen editieren</translation>
    </message>
    <message>
        <source>Panel &amp;Name:</source>
        <translation>Paneel &amp;Name:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
</context>
<context>
    <name>RDExceptionDialog</name>
    <message>
        <source>Rivendell Exception Report</source>
        <translation>Rivendell Fehlerreport</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schliessen</translation>
    </message>
    <message>
        <source>Text (*.txt *.TXT)
All Files (*.*)</source>
        <translation>Text (*.txt *.TXT)
Alle Dateien (*.*)</translation>
    </message>
    <message>
        <source>Export File</source>
        <translation>Datei Exportieren</translation>
    </message>
    <message>
        <source>The file</source>
        <translation>Die Datei</translation>
    </message>
    <message>
        <source>already exists!
Overwrite?</source>
        <translation>existiert bereits!
Überschreiben?</translation>
    </message>
    <message>
        <source>File Exists</source>
        <translation>Datei existiert</translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation>Kann die Datei nicht öffnen</translation>
    </message>
    <message>
        <source>for writing!</source>
        <translation>zum schreiben!</translation>
    </message>
    <message>
        <source>File Error</source>
        <translation>Dateifehler</translation>
    </message>
</context>
<context>
    <name>RDExportSettingsDialog</name>
    <message>
        <source>Edit Export Settings</source>
        <translation>Exporteinstellungen editieren</translation>
    </message>
    <message>
        <source>&amp;Channels:</source>
        <translation>&amp;Kanäle:</translation>
    </message>
    <message>
        <source>&amp;Sample Rate:</source>
        <translation>&amp;Sample Rate:</translation>
    </message>
    <message>
        <source>&amp;Bitrate:</source>
        <translation>&amp;Bitrate:</translation>
    </message>
    <message>
        <source>&amp;Quality:</source>
        <translation>&amp;Qualität:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <source>PCM16</source>
        <translation>PCM16</translation>
    </message>
    <message>
        <source>FLAC</source>
        <translation>FLAC</translation>
    </message>
    <message>
        <source>MPEG Layer 2</source>
        <translation>MPEG Layer 2</translation>
    </message>
    <message>
        <source>MPEG Layer 3</source>
        <translation>MPEG Layer 3</translation>
    </message>
    <message>
        <source>OggVorbis</source>
        <translation>OggVorbis</translation>
    </message>
    <message>
        <source>VBR</source>
        <translation>VBR</translation>
    </message>
    <message>
        <source>32 kbps</source>
        <translation>32 kbps</translation>
    </message>
    <message>
        <source>64 kbps</source>
        <translation>64 kbps</translation>
    </message>
    <message>
        <source>96 kbps</source>
        <translation>96 kbps</translation>
    </message>
    <message>
        <source>128 kbps</source>
        <translation>128 kbps</translation>
    </message>
    <message>
        <source>160 kbps</source>
        <translation>160 kbps</translation>
    </message>
    <message>
        <source>192 kbps</source>
        <translation>192 kbps</translation>
    </message>
    <message>
        <source>224 kbps</source>
        <translation>224 kbps</translation>
    </message>
    <message>
        <source>256 kbps</source>
        <translation>256 kbps</translation>
    </message>
    <message>
        <source>288 kbps</source>
        <translation>288 kbps</translation>
    </message>
    <message>
        <source>320 kbps</source>
        <translation>320 kbps</translation>
    </message>
    <message>
        <source>352 kbps</source>
        <translation>352 kbps</translation>
    </message>
    <message>
        <source>384 kbps</source>
        <translation>384 kbps</translation>
    </message>
    <message>
        <source>416 kbps</source>
        <translation>416 kbps</translation>
    </message>
    <message>
        <source>448 kbps</source>
        <translation>448 kbps</translation>
    </message>
    <message>
        <source>48 kbps</source>
        <translation>48 kbps</translation>
    </message>
    <message>
        <source>56 kbps</source>
        <translation>56 kbps</translation>
    </message>
    <message>
        <source>80 kbps</source>
        <translation>80 kbps</translation>
    </message>
    <message>
        <source>112 kbps</source>
        <translation>112 kbps</translation>
    </message>
    <message>
        <source>40 kbps</source>
        <translation>40 kbps</translation>
    </message>
    <message>
        <source>8 kbps</source>
        <translation>8 kbps</translation>
    </message>
    <message>
        <source>16 kbps</source>
        <translation>16 kbps</translation>
    </message>
    <message>
        <source>24 kbps</source>
        <translation>24 kbps</translation>
    </message>
    <message>
        <source>144 kbps</source>
        <translation>144 kbps</translation>
    </message>
    <message>
        <source>PCM24</source>
        <translation type="unfinished">PCM24</translation>
    </message>
</context>
<context>
    <name>RDGetAth</name>
    <message>
        <source>Enter ATH</source>
        <translation>ATH eingeben</translation>
    </message>
    <message>
        <source>Enter the agreggate tuning hours (ATH)
figure for the report period.
(Supplied by your streaming provider).</source>
        <translation>Enter the agreggate tuning hours (ATH)
figure for the report period.
(Fragen sie ihren Streamanbieter).</translation>
    </message>
    <message>
        <source>ATH:</source>
        <translation>ATH:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <source>Invalid ATH</source>
        <translation>Ungültiger ATH</translation>
    </message>
    <message>
        <source>You must provide a valid ATH figure!</source>
        <translation>Sie müssen eine gültige ATH-figure angeben!</translation>
    </message>
</context>
<context>
    <name>RDGetPasswd</name>
    <message>
        <source>Enter Password</source>
        <translation>Passwort eingeben</translation>
    </message>
    <message>
        <source>Enter password</source>
        <translation>Passwort eingeben</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
</context>
<context>
    <name>RDGpioSelector</name>
    <message>
        <source>Pin:</source>
        <translation>PIN:</translation>
    </message>
</context>
<context>
    <name>RDImportAudio</name>
    <message>
        <source>Import/Export Audio File</source>
        <translation>Audiodatei importieren/exportieren</translation>
    </message>
    <message>
        <source>Import File</source>
        <translation>Datei importieren</translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation>Dateiname:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>au&amp;swählen</translation>
    </message>
    <message>
        <source>Import file metadata</source>
        <translation>Dateimetadaten importieren</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Kanäle:</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>Autotrim</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Level:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dBFS</translation>
    </message>
    <message>
        <source>Export File</source>
        <translation>Datei Exportieren</translation>
    </message>
    <message>
        <source>Export file metadata</source>
        <translation>Datei-Metadaten exportieren</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>S&amp;et</source>
        <translation>S&amp;etzen</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalisieren</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>&amp;Importieren</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importieren</translation>
    </message>
    <message>
        <source>Import Audio File</source>
        <translation>Audiodatei importieren</translation>
    </message>
    <message>
        <source>File does not exist!</source>
        <translation>Datei existiert nicht!</translation>
    </message>
    <message>
        <source>Cannot open file!</source>
        <translation type="obsolete">Kann die Datei nicht öffnen!</translation>
    </message>
    <message>
        <source>Unsupported file type!</source>
        <translation type="obsolete">Dateityp nicht unterstützt!</translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation type="obsolete">Audiomaterial existiert</translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation type="obsolete">Das wird die existierende Aufnahme löschen.
Wollen sie fortfahren?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation type="obsolete">Zwischenablage leeren</translation>
    </message>
    <message>
        <source>Importing this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation type="obsolete">Diesen Cut zu importieren wird die Zwischen-
ablage löschen! Fortfahren?</translation>
    </message>
    <message>
        <source>Import Complete</source>
        <translation>Import abgeschlossen</translation>
    </message>
    <message>
        <source>Import complete!</source>
        <translation>Import abgeschlossen!</translation>
    </message>
    <message>
        <source>Import Aborted</source>
        <translation type="obsolete">Import abgebrochen</translation>
    </message>
    <message>
        <source>The import has been aborted.</source>
        <translation type="obsolete">Der Import wurde abgebrochen.</translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation type="obsolete">Import fehlgeschlagen</translation>
    </message>
    <message>
        <source>The importer encountered an error.
Please check your importer configuration and try again.</source>
        <translation type="obsolete">Der Importer ist auf einen Fehler gestoßen.
Bitte überprüfen sie die Importer-Einstellungen und versuchen sie es erneut.</translation>
    </message>
    <message>
        <source>File Exists</source>
        <translation>Datei existiert</translation>
    </message>
    <message>
        <source>The selected file already exists!
Do you want to overwrite it?</source>
        <translation>Die ausgewählte Datei existiert
bereits! Überschreiben?</translation>
    </message>
    <message>
        <source>File Error</source>
        <translation type="obsolete">Dateifehler</translation>
    </message>
    <message>
        <source>Cannot open file in archive!</source>
        <translation type="obsolete">Kann die Datei im Archiv nicht öffnen!</translation>
    </message>
    <message>
        <source>Unsupported file type in archive!</source>
        <translation type="obsolete">Nicht unterstützter Dateityp im Archiv!</translation>
    </message>
    <message>
        <source>No Access</source>
        <translation type="obsolete">Kein Zugriff</translation>
    </message>
    <message>
        <source>Unable to open the file for writing!</source>
        <translation type="obsolete">Kann die Logdatei nicht zum schreiben öffnen!</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>Export Complete</source>
        <translation>Export vollständig</translation>
    </message>
    <message>
        <source>Export complete!</source>
        <translation>Export vollständig!</translation>
    </message>
    <message>
        <source>Export Aborted</source>
        <translation type="obsolete">Export abgebrochen</translation>
    </message>
    <message>
        <source>The export has been aborted.</source>
        <translation type="obsolete">Der Export wurde abgebrochen.</translation>
    </message>
    <message>
        <source>Export Failed</source>
        <translation type="obsolete">Export fehlgeschlagen</translation>
    </message>
    <message>
        <source>The Exporter encountered an error.
Please check your configuration and try again.</source>
        <translation type="obsolete">Der Exporter ist auf einen Fehler gestoßen.
Bitte Kofiguration prüfen und erneut versuchen.</translation>
    </message>
    <message>
        <source>Export Error</source>
        <translation>Exportfehler</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Importfehler</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>RDIntegerDialog</name>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <source>Set Value</source>
        <translation>Wert setzen</translation>
    </message>
</context>
<context>
    <name>RDIntegerEdit</name>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Set Value</source>
        <translation>Wert setzen</translation>
    </message>
</context>
<context>
    <name>RDLicense</name>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schliessen</translation>
    </message>
    <message>
        <source>GNU Public License v2</source>
        <translation>GNU Public License v2</translation>
    </message>
</context>
<context>
    <name>RDListGroups</name>
    <message>
        <source>Select Group</source>
        <translation>Gruppe wählen</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation>NAME</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>BESCHREIBUNG</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
</context>
<context>
    <name>RDListLogs</name>
    <message>
        <source>Select Log - User: </source>
        <translation>Logbenutzer auswählen:</translation>
    </message>
    <message>
        <source>Select Log</source>
        <translation>Log auswählen</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation>NAME</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>BESCHREIBUNG</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation>SERVICE</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>RDListSelector</name>
    <message>
        <source>Available Services</source>
        <translation>Verfügbare Services</translation>
    </message>
    <message>
        <source>Add &gt;&gt;</source>
        <translation>Hinzufügen &gt;&gt;</translation>
    </message>
    <message>
        <source>&lt;&lt; Remove</source>
        <translation>&lt;&lt; Entfernen</translation>
    </message>
    <message>
        <source>Active Services</source>
        <translation>Aktive Services</translation>
    </message>
</context>
<context>
    <name>RDLogLine</name>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Unbekannt</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="obsolete">Handbuch</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="obsolete">Play</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="obsolete">Segue</translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="obsolete">Zeit</translation>
    </message>
    <message>
        <source>Panel</source>
        <translation type="obsolete">Panel</translation>
    </message>
    <message>
        <source>Macro</source>
        <translation type="obsolete">Makro</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="obsolete">PLAY</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="obsolete">SEGUE</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="obsolete">STOP</translation>
    </message>
    <message>
        <source>UNKNOWN</source>
        <translation type="obsolete">UNBEKANNT</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="obsolete">Audio</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation type="obsolete">Marker</translation>
    </message>
    <message>
        <source>Open Bracket</source>
        <translation type="obsolete">Klammer öffnen</translation>
    </message>
    <message>
        <source>Close Bracket</source>
        <translation type="obsolete">Klammer schließen</translation>
    </message>
    <message>
        <source>ChainTo</source>
        <translation type="obsolete">ChainTo</translation>
    </message>
    <message>
        <source>Track</source>
        <translation type="obsolete">Track</translation>
    </message>
    <message>
        <source>Link</source>
        <translation type="obsolete">Link</translation>
    </message>
    <message>
        <source>Traffic</source>
        <translation type="obsolete">Traffic</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="obsolete">Musik</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation type="obsolete">RDLogManager</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation type="obsolete">Tracker</translation>
    </message>
</context>
<context>
    <name>RDPanelButton</name>
    <message>
        <source>No Audio</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDPasswd</name>
    <message>
        <source>Change Password</source>
        <translation>Paßwort ändern</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Paßwort:</translation>
    </message>
    <message>
        <source>C&amp;onfirm:</source>
        <translation>&amp;Bestätigen:</translation>
    </message>
    <message>
        <source>Password Mismatch</source>
        <translation>Paßworte stimmen nicht überein</translation>
    </message>
    <message>
        <source>The passwords don&apos;t match,
please try again!</source>
        <translation>Die Paßworte stimmen nicht überein,
bitte erneut versuchen!</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>RDRecording</name>
    <message>
        <source>Recording</source>
        <translation type="obsolete">Aufnahme</translation>
    </message>
    <message>
        <source>Macro Event</source>
        <translation type="obsolete">Makro Event</translation>
    </message>
    <message>
        <source>Switch Event</source>
        <translation type="obsolete">Schalt-Event</translation>
    </message>
    <message>
        <source>Playout</source>
        <translation type="obsolete">Playout</translation>
    </message>
    <message>
        <source>Download</source>
        <translation type="obsolete">Download</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation type="obsolete">Upload</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="obsolete">Ok</translation>
    </message>
    <message>
        <source>Short Length</source>
        <translation type="obsolete">Kurze Länge</translation>
    </message>
    <message>
        <source>Low Level</source>
        <translation type="obsolete">Niedriger Level</translation>
    </message>
    <message>
        <source>High Level</source>
        <translation type="obsolete">Hoher Level</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="obsolete">Herunterladen</translation>
    </message>
    <message>
        <source>Uploading</source>
        <translation type="obsolete">Hochladen</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation type="obsolete">Serverfehler</translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="obsolete">Interner Fehler</translation>
    </message>
    <message>
        <source>Interrupted</source>
        <translation type="obsolete">Unterbrochen</translation>
    </message>
    <message>
        <source>Playing</source>
        <translation type="obsolete">Abspielen</translation>
    </message>
    <message>
        <source>Waiting</source>
        <translation type="obsolete">Warten</translation>
    </message>
    <message>
        <source>Device Busy</source>
        <translation type="obsolete">Gerät beschäftigt</translation>
    </message>
    <message>
        <source>No Such Cart/Cut</source>
        <translation type="obsolete">Kein solcher Cart/Cut</translation>
    </message>
    <message>
        <source>Unknown Audio Format</source>
        <translation type="obsolete">Unbekanntes Audioformat</translation>
    </message>
</context>
<context>
    <name>RDReport</name>
    <message>
        <source>CBSI DeltaFlex Traffic Reconciliation v2.01</source>
        <translation type="obsolete">CBSI DeltaFlex Traffic Reconciliation v2.01</translation>
    </message>
    <message>
        <source>Text Log</source>
        <translation type="obsolete">Text Log</translation>
    </message>
    <message>
        <source>ASCAP/BMI Electronic Music Report</source>
        <translation type="obsolete">ASCAP/BMI Electronic Music Report</translation>
    </message>
    <message>
        <source>Technical Playout Report</source>
        <translation type="obsolete">Technical Playout Report</translation>
    </message>
    <message>
        <source>SoundExchange Statutory License Report</source>
        <translation type="obsolete">SoundExchange Statutory License Report</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Unbekannt</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="obsolete">Andere</translation>
    </message>
    <message>
        <source>AM</source>
        <translation type="obsolete">AM</translation>
    </message>
    <message>
        <source>FM</source>
        <translation type="obsolete">FM</translation>
    </message>
    <message>
        <source>Report complete!</source>
        <translation type="obsolete">Report vollständig!</translation>
    </message>
    <message>
        <source>Report canceled!</source>
        <translation type="obsolete">Report abgebrochen!</translation>
    </message>
    <message>
        <source>Unable to open report file!</source>
        <translation type="obsolete">Kann Reportdatei nicht öffnen!</translation>
    </message>
    <message>
        <source>RadioTraffic.com Traffic Reconciliation</source>
        <translation type="obsolete">RadioTraffic.com Traffic Reconciliation</translation>
    </message>
    <message>
        <source>VisualTraffic Reconciliation</source>
        <translation type="obsolete">VisualTraffic Reconciliation</translation>
    </message>
    <message>
        <source>CounterPoint Traffic Reconciliation</source>
        <translation type="obsolete">CounterPoint Traffic Reconciliation</translation>
    </message>
    <message>
        <source>Music1 Reconciliation</source>
        <translation type="obsolete">Music1 Reconciliation</translation>
    </message>
</context>
<context>
    <name>RDSoundPanel</name>
    <message>
        <source>Play All</source>
        <translation>alles spielen</translation>
    </message>
    <message>
        <source>Play Hook</source>
        <translation>Hook spielen</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alles</translation>
    </message>
    <message>
        <source>Setup</source>
        <translation>setup</translation>
    </message>
    <message>
        <source>Cart</source>
        <translation>Cart</translation>
    </message>
    <message>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
</context>
<context>
    <name>RDSqlDatabaseStatus</name>
    <message>
        <source>Database connection restored.</source>
        <translation>Datenbankverbindung wiederhergestellt.</translation>
    </message>
    <message>
        <source>Database connection failed : </source>
        <translation>Datenbankverbindung fehlgeschlagen:</translation>
    </message>
</context>
<context>
    <name>RDStereoMeter</name>
    <message>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <source>CLIP</source>
        <translation>CLIP</translation>
    </message>
</context>
<context>
    <name>RDSvc</name>
    <message>
        <source>The following events were not placed:
</source>
        <translation>Die folgenen Events wurden nicht plaziert:</translation>
    </message>
    <message>
        <source>[unknown cart]</source>
        <translation>[unbekannter Cart]</translation>
    </message>
    <message>
        <source>Event Fill Errors
</source>
        <translation>Event-Füllfehler</translation>
    </message>
</context>
</TS>
